
KIS2 = {};

function KIS2.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Cutter, specializations) and SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function KIS2:load(xmlFile)

	self.KIS2 = {};
	self.KIS2.speed = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.kis#speed"), 11);
	self.KIS2.offset = 10;
	self.KIS2.speedScaleTime = 5000;
	self.KIS2.speedScaleBackup = self.reelSpeedScale;
	self.KIS2.rollSpeedBackup = self.rollNodes[1].speed;
	self.reelSpeedScale = 0;
	for _, rollNode in pairs(self.rollNodes) do
		rollNode.speed = 0;
	end;
	
	self.blades = {};
	
	local horizontal = {};
	horizontal.node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.blades#horizontal"));
	horizontal.max = getXMLFloat(xmlFile, "vehicle.blades#horizMax");
	horizontal.speed = getXMLFloat(xmlFile, "vehicle.blades#horizSpeed") * 1000;
	horizontal.dir = 1;
	
	self.blades.horizontal = horizontal;
	
	self.oblic = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.oblic#index"));
	self.oblic2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.oblic2#index"));
	
	setVisibility(self.oblic, true)
	setVisibility(self.oblic2, true)
	self.partsActive = true;
	self.partsActive2 = true;
		
end;

function KIS2:delete()
end;

function KIS2:mouseEvent(posX, posY, isDown, isUp, button)
end;

function KIS2:keyEvent(unicode, sym, modifier, isDown)

end;

function KIS2:update(dt)

	Utils.setEmittingState(self.threshingParticleSystems, (self.reelStarted and self.lastCutterAreaBiggerZero));
	
	if self:getIsActive() and self.reelStarted then
	
		if self.attacherVehicle ~= nil and self.attacherVehicle.allowsThreshing ~= nil then
			if not self.attacherVehicle.allowsThreshing then
				self.lastAreaBiggerZero = false;
				if self.lastAreaBiggerZero ~= self.lastAreaBiggerZeroSent then
					self:raiseDirtyFlags(self.cutterGroundFlag);
					self.lastAreaBiggerZeroSent = self.lastAreaBiggerZero;
				end;
			end;
		end;
		

		local percent = math.max(0.85, math.min((self.lastSpeed*3600) / self.KIS2.speed, 1.3));
		
		local speedScale = Utils.getMovedLimitedValues({self.reelSpeedScale}, {self.KIS2.speedScaleBackup * percent}, {0}, 1, self.KIS2.speedScaleTime, dt, false);
		self.reelSpeedScale = speedScale[1];
		for _, rollNode in pairs(self.rollNodes) do
			local rollSpeed = Utils.getMovedLimitedValues({rollNode.speed}, {self.KIS2.rollSpeedBackup * percent}, {0}, 1, self.KIS2.speedScaleTime, dt, false);
			rollNode.speed = rollSpeed[1];
		end;

		if self.blades.horizontal.node ~= nil then
			local x,_,_ = getTranslation(self.blades.horizontal.node);
			if x < 0.005 or x > (self.blades.horizontal.max - 0.005) then
				self.blades.horizontal.dir = math.abs(self.blades.horizontal.dir - 1);
			end;
			local newTrans = Utils.getMovedLimitedValues({x}, {self.blades.horizontal.max}, {0}, 1, self.blades.horizontal.speed / percent, dt, self.blades.horizontal.dir ~= 0);
			setTranslation(self.blades.horizontal.node, unpack(newTrans), 0, 0);
		end;
	else
		if self.reelSpeedScale ~= 0 or self.rollNodes[1].speed ~= 0 then
			local percent = math.max(0.85, math.min((self.lastSpeed*3600) / self.KIS2.speed, 1.5));
			
			local speedScale = Utils.getMovedLimitedValues({self.reelSpeedScale}, {self.KIS2.speedScaleBackup * percent}, {0}, 1, self.KIS2.speedScaleTime*1.5, dt, true);
			self.reelSpeedScale = speedScale[1];
			rotate(self.reelNode, -dt*self.reelSpeed*self.reelSpeedScale, 0, 0);
			for _, rollNode in pairs(self.rollNodes) do
				local rollSpeed = Utils.getMovedLimitedValues({rollNode.speed}, {self.KIS2.rollSpeedBackup * percent}, {0}, 1, self.KIS2.speedScaleTime*1.5, dt, true);
				rollNode.speed = rollSpeed[1];
				rotate(rollNode.node, -dt*rollNode.speed, 0, 0);
			end;
			
			local atx, aty, atz = getRotation(self.reelNode);
			for i=1, self.spikesCount do
				local spike = getChildAt(self.spikesRootNode, i-1);
				setRotation(spike, -atx, aty, atz);
			end;
			
		end;
	end;
	
	if self.inrange or self.isEntered then
		if self.partsActive then
		setVisibility(self.oblic, self.partsActive)
			g_currentMission:addHelpButtonText(g_i18n:getText("ju6_1"), InputBinding.ju6_ob);
		else
		setVisibility(self.oblic, self.partsActive, false)
			g_currentMission:addHelpButtonText(g_i18n:getText("ju6_1"), InputBinding.ju6_ob);
		
		end;	
	end;
	
	if self.inrange or self.isEntered then
		if self.partsActive then
		setVisibility(self.oblic2, self.partsActive2)
			g_currentMission:addHelpButtonText(g_i18n:getText("ju6_2"), InputBinding.ju6_ob2);
	
		else
	
		setVisibility(self.oblic2, self.partsActive2, false)
			g_currentMission:addHelpButtonText(g_i18n:getText("ju6_2"), InputBinding.ju6_ob2);
	end;
	end;
	
	if self.inrange  or self.isEntered then
		if InputBinding.hasEvent (InputBinding.ju6_ob) then
			self.partsActive = not self.partsActive;
		end;
		if InputBinding.hasEvent (InputBinding.ju6_ob2) then
			self.partsActive2 = not self.partsActive2;
		end;
	end;
	
end;

function KIS2:updateTick(dt)

	if self.attacherVehicle and g_currentMission.player ~= nil then
		-- Getting the distance between the player and the implement 
		local nearestDistance = 4.0; --max distance allowed
		local px, py, pz = getWorldTranslation(self.rootNode); 
		local vx, vy, vz = getWorldTranslation(g_currentMission.player.rootNode);
		local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);	
		if distance < nearestDistance then
			self.inrange = true; 
		else
			self.inrange = false; 
		end;
	end;

end;

function KIS2:onLeave()

end;

function KIS2:draw()


end;